# Manage a service using docker-compose with an env file
define utils::docker_compose_service_env(
  String           $compose_file,
  String           $description,
  String           $envfile = '/dev/null',
  String           $docker_svc_names = '', # empty should bring up everything in compose file
  Optional[String] $service_name = undef,
  Boolean          $pull_on_start = false,
  Array[String]    $service_extras = [],
  Optional[String] $service_alias = undef,
  Optional[String] $start_command = undef,
) {
  include sunet::systemd_reload

  $_service_name = $service_name ? {
    undef => $name,
    default => $service_name,
  }

  $_template = 'utils/dockerhost_env/compose2.service.erb'

  file {
    "/etc/systemd/system/${_service_name}.service":
      content => template($_template),
      notify  => [Class['sunet::systemd_reload'],
                  ],
      ;
  }


  service { $_service_name :
    ensure   => 'running',
    enable   => true,
    require  => File["/etc/systemd/system/${_service_name}.service"],
    provider => 'systemd',  # puppet is really bad at figuring this out
  }
}
